Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/server.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorValdnet <47037905+Valdnet@users.noreply.github.com>2021-04-15 16:42:43 +0300
committerMorris Jobke <hey@morrisjobke.de>2021-05-20 10:26:38 +0300
commite7648c2fddbb80c1e3e61e916be2fbd794bd94ec (patch)
treea96f4384b711712ba81a7ff50844217727024f3c
parent11dc65869d49e5820e614bdff68d15caec5e104e (diff)
l10n: Unify spelling
Spelling unification in Nextcloud applications.
-rw-r--r--lib/private/Share20/Manager.php26
1 files changed, 13 insertions, 13 deletions
diff --git a/lib/private/Share20/Manager.php b/lib/private/Share20/Manager.php
index cc1bd58f254..70facc442c5 100644
--- a/lib/private/Share20/Manager.php
+++ b/lib/private/Share20/Manager.php
@@ -252,7 +252,7 @@ class Manager implements IManager {
} elseif ($share->getShareType() === IShare::TYPE_ROOM) {
} elseif ($share->getShareType() === IShare::TYPE_DECK) {
} else {
// We can't handle other types yet
throw new \InvalidArgumentException('unknown share type');
}
@@ -264,7 +264,7 @@ class Manager implements IManager {
// Cannot share with yourself
if ($share->getShareType() === IShare::TYPE_USER &&
$share->getSharedWith() === $share->getSharedBy()) {
- throw new \InvalidArgumentException('Can’t share with yourself');
+ throw new \InvalidArgumentException('Cannot share with yourself');
}
// The path should be set
@@ -278,14 +278,14 @@ class Manager implements IManager {
throw new \InvalidArgumentException('Path should be either a file or a folder');
}
// And you can't share your rootfolder
if ($this->userManager->userExists($share->getSharedBy())) {
$userFolder = $this->rootFolder->getUserFolder($share->getSharedBy());
} else {
$userFolder = $this->rootFolder->getUserFolder($share->getShareOwner());
}
if ($userFolder->getId() === $share->getNode()->getId()) {
- throw new \InvalidArgumentException('You can’t share your root folder');
+ throw new \InvalidArgumentException('You cannot share your root folder');
}
// Check if we actually have share permissions
@@ -796,7 +796,7 @@ class Manager implements IManager {
// Cannot share with the owner
if ($share->getShareType() === IShare::TYPE_USER &&
$share->getSharedWith() === $share->getShareOwner()) {
- throw new \InvalidArgumentException('Can’t share with the share owner');
+ throw new \InvalidArgumentException('Cannot share with the share owner');
}
// Generate the target
@@ -964,9 +964,9 @@ class Manager implements IManager {
throw new \InvalidArgumentException('Share does not have a full id');
}
// We can't change the share type!
if ($share->getShareType() !== $originalShare->getShareType()) {
- throw new \InvalidArgumentException('Can’t change share type');
+ throw new \InvalidArgumentException('Cannot change share type');
}
// We can only change the recipient on user shares
@@ -978,7 +978,7 @@ class Manager implements IManager {
// Cannot share with the owner
if ($share->getShareType() === IShare::TYPE_USER &&
$share->getSharedWith() === $share->getShareOwner()) {
- throw new \InvalidArgumentException('Can’t share with the share owner');
+ throw new \InvalidArgumentException('Cannot share with the share owner');
}
$this->generalCreateChecks($share);
@@ -1013,7 +1013,7 @@ class Manager implements IManager {
* Cannot enable the getSendPasswordByTalk if there is no password set
*/
if (empty($plainTextPassword) && $share->getSendPasswordByTalk()) {
- throw new \InvalidArgumentException('Can’t enable sending the password by Talk with an empty password');
+ throw new \InvalidArgumentException('Cannot enable sending the password by Talk with an empty password');
}
/**
@@ -1023,10 +1023,10 @@ class Manager implements IManager {
*/
if (!$updatedPassword && $share->getShareType() === IShare::TYPE_EMAIL) {
if (!$originalShare->getSendPasswordByTalk() && $share->getSendPasswordByTalk()) {
- throw new \InvalidArgumentException('Can’t enable sending the password by Talk without setting a new password');
+ throw new \InvalidArgumentException('Cannot enable sending the password by Talk without setting a new password');
}
if ($originalShare->getSendPasswordByTalk() && !$share->getSendPasswordByTalk()) {
- throw new \InvalidArgumentException('Can’t disable sending the password by Talk without setting a new password');
+ throw new \InvalidArgumentException('Cannot disable sending the password by Talk without setting a new password');
}
}
@@ -1246,7 +1246,7 @@ class Manager implements IManager {
public function moveShare(IShare $share, $recipientId) {
if ($share->getShareType() === IShare::TYPE_LINK
|| $share->getShareType() === IShare::TYPE_EMAIL) {
- throw new \InvalidArgumentException('Can’t change target of link share');
+ throw new \InvalidArgumentException('Cannot change target of link share');
}
if ($share->getShareType() === IShare::TYPE_USER && $share->getSharedWith() !== $recipientId) {
@@ -1447,7 +1447,7 @@ class Manager implements IManager {
* @throws ShareNotFound
*/
public function getShareByToken($token) {
// tokens can't be valid local user names
if ($this->userManager->userExists($token)) {
throw new ShareNotFound();
}
@@ -252,7 +252,7 @@ class Manager implements IManager {
} elseif ($share->getShareType() === IShare::TYPE_DECK) {
} else {
- // We can't handle other types yet
+ // We cannot handle other types yet
throw new \InvalidArgumentException('unknown share type');
}
@@ -278,14 +278,14 @@ class Manager implements IManager {
throw new \InvalidArgumentException('Path should be either a file or a folder');
}
- // And you can't share your rootfolder
+ // And you cannot share your rootfolder
if ($this->userManager->userExists($share->getSharedBy())) {
$userFolder = $this->rootFolder->getUserFolder($share->getSharedBy());
@@ -964,9 +964,9 @@ class Manager implements IManager {
throw new \InvalidArgumentException('Share does not have a full id');
}
- // We can't change the share type!
+ // We cannot change the share type!
if ($share->getShareType() !== $originalShare->getShareType()) {
@@ -1447,7 +1447,7 @@ class Manager implements IManager {
*/
public function getShareByToken($token) {
- // tokens can't be valid local user names
+ // tokens cannot be valid local user names
if ($this->userManager->userExists($token)) {
throw new ShareNotFound();